import SwiftUI
import HighlightedTextEditor
import SFSafeSymbols

struct PostContentView: View {

    @ObservedObject
    var post: Post

    @Environment(\.language)
    private var language

    init(post: Post) {
        self.post = post
    }

    var body: some View {
        LocalizedPostContentView(
            post: post.localized(in: language),
            other: post.localized(in: language.next),
            tags: $post.tags,
            page: $post.linkedPage)
    }
}

extension PostContentView: MainContentView {

    init(item: Post) {
        self.post = item
    }

    static let itemDescription = "a post"
}

#Preview(traits: .fixedLayout(width: 450, height: 600)) {
    List {
        PostContentView(post: .Mock.hike2)
            .listRowSeparator(.hidden)
            .environment(\.language, ContentLanguage.german)
        PostContentView(post: .Mock.hike)
            .listRowSeparator(.hidden)
    }
    .environmentObject(Content.mock)
}
